==> tine20-allinone_2019.12.5.tar.bz2: Tasks/js/Tasks-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ru\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""
 ,""
 ,""

]
, "Task, Tasks"
: [
  "Задачи"
 ,"Задачи"
 ,"Задач"
 ,"Задач"

]
, "Percent"
: "Процент"

, "Completed"
: "Закончено"

, "Due"
: "Окончание"

, "Class"
: ""

, "Description"
: "Описание"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Организатор"

, "Priority"
: "Приоритет"

, "Status, Status"
: [
  "Состояние"
 ,"Состояния"
 ,"Состояния"
 ,"Состояния"

]
, "Lead"
: "Предложение"

, "Telephone"
: "Телефон"

, "Email"
: "Электронная почта"

, "Add New Task"
: "Добавить новую задачу"

, "You have to supply a due date, because an alarm ist set!"
: "Вы должны поставить дату для оповещения!"

, "Summary"
: "Сводка"

, "Due date"
: "Дата завершения"

, "Add Responsible ..."
: "Добавить Ответственных ..."

, "Notes"
: "Примечания"

, "Enter description..."
: "Введите описание..."

, "Percentage"
: "Процентное отношение"

, "Tasks"
: "Задачи"

, "to do list, to do lists"
: [
  "список работ"
 ,"список работ"
 ,"списки работ"
 ,"списки работ"

]
, "to do lists"
: "списки работ"

, "Quick Search"
: "Быстрый поиск"

, "Due Date"
: "Дата завершения"

, "Responsible"
: "Ответственный"

, "Last Modified Time"
: "Время последнего изменения"

, "Last Modified By"
: "Последнее изменение"

, "Creation Time"
: "Время создания"

, "Created By"
: "Создана"

, "New Task"
: "Новая задача"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Вы действительно хотите удалить выбранную задачу"
 ,"Вы действительно хотите удалить выбранную задачу"
 ,"Вы действительно хотите удалить выбранные задачи"
 ,"Вы действительно хотите удалить выбранные задачи"

]
, "Attachments"
: ""

, "Tags"
: "Теги"

, "Lead name"
: "Название предложения"

, "Add a task..."
: "Добавить задачу..."

, "All my tasks"
: "Все мои задачи"

, "Default Favorite"
: "Избранное по-умолчанию"

, "The default favorite which is loaded on Tasks startup"
: "Будет загружено по-умолчанию при загрузке задач"

, "Default Task List"
: "Список задач по умолчанию"

, "The default task list to create new tasks in."
: "Список задач для создания новых задач по умолчанию"

, "Tasks status available"
: "Доступно состояние задач"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Возможные состояния задач. Пожалуйста, обратите внимание, что дополнительные состояния задач могут повлиять на другие задачи при экспорте или синхронизации."

, "No response"
: "Нет ответа"

, "Cancelled"
: "Отменено"

, "In process"
: "в работе"

, "Task priorities available"
: "Доступен приоритет задачи"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Возможные приоритеты задач. Обратите внимание, что дополнительные значения могут повлиять на другие задачи при экспорте или синхронизации."

, "low"
: "низкий"

, "normal"
: "нормальный"

, "high"
: "высокий"

, "urgent"
: "неотложный"

, "manage shared task lists"
: "управление списками общих задач"

, "Create new shared tasks lists"
: "Создать новый список общих задач"

, "manage shared tasks favorites"
: "управлять избранным в общих задачах"

, "Create or update shared tasks favorites"
: "Создание или обновление избранных в общих задачах"

, "%s's personal tasks"
: "%s личные задачи"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Все задачи моих списков задач"

, "My open tasks"
: "Мои открытые задачи"

, "My open tasks this week"
: "Мои открытые задачи на этой неделе"

, "All tasks for me"
: "Все задачи для меня"

, "All tasks that I am responsible for"
: "Все задачи, за которые я отвечаю"

, "Last modified by me"
: "Последний раз изменено мной"

, "All tasks that I have last modified"
: "Все задачи, последний раз которые были изменены мной"

, "Tasks without responsible"
: "Задача без ответственного лица"

, "GENDER_Task"
: ""

, "Task"
: "Задачи"

, "Status"
: "Состояние"

, "to do list"
: "список работ"

, "Do you really want to delete the selected task?"
: "Вы действительно хотите удалить выбранную задачу"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: "Добавить новую задачу"

, "You have to supply a due date, because an alarm ist set!"
: "Вы должны поставить дату для оповещения!"

, "Summary"
: "Сводка"

, "Due date"
: "Дата завершения"

, "Priority"
: "Приоритет"

, "Organizer"
: "Организатор"

, "Add Responsible ..."
: "Добавить Ответственных ..."

, "Notes"
: "Примечания"

, "Enter description..."
: "Введите описание..."

, "Percentage"
: "Процентное отношение"

, "Status, Status"
: [
  "Состояние"
 ,"Состояния"
 ,"Состояния"
 ,"Состояния"

]
, "Completed"
: "Закончено"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Вы действительно хотите удалить выбранную задачу"
 ,"Вы действительно хотите удалить выбранную задачу"
 ,"Вы действительно хотите удалить выбранные задачи"
 ,"Вы действительно хотите удалить выбранные задачи"

]
, "Attachments"
: ""

, "Tags"
: "Теги"

, "Lead name"
: "Название предложения"

, "Add a task..."
: "Добавить задачу..."

, "Due Date"
: "Дата завершения"

, "Percent"
: "Процент"

, "Responsible"
: "Ответственный"

, "Task, Tasks"
: [
  "Задачи"
 ,"Задачи"
 ,"Задач"
 ,"Задач"

]
, "Tasks"
: "Задачи"

, "to do list, to do lists"
: [
  "список работ"
 ,"список работ"
 ,"списки работ"
 ,"списки работ"

]
, "to do lists"
: "списки работ"

, "Quick Search"
: "Быстрый поиск"

, "Last Modified Time"
: "Время последнего изменения"

, "Last Modified By"
: "Последнее изменение"

, "Creation Time"
: "Время создания"

, "Created By"
: "Создана"

, "New Task"
: "Новая задача"

, "All my tasks"
: "Все мои задачи"

, "Default Favorite"
: "Избранное по-умолчанию"

, "The default favorite which is loaded on Tasks startup"
: "Будет загружено по-умолчанию при загрузке задач"

, "Default Task List"
: "Список задач по умолчанию"

, "The default task list to create new tasks in."
: "Список задач для создания новых задач по умолчанию"

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: "Доступно состояние задач"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Возможные состояния задач. Пожалуйста, обратите внимание, что дополнительные состояния задач могут повлиять на другие задачи при экспорте или синхронизации."

, "No response"
: "Нет ответа"

, "Cancelled"
: "Отменено"

, "In process"
: "в работе"

, "Task priorities available"
: "Доступен приоритет задачи"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Возможные приоритеты задач. Обратите внимание, что дополнительные значения могут повлиять на другие задачи при экспорте или синхронизации."

, "low"
: "низкий"

, "normal"
: "нормальный"

, "high"
: "высокий"

, "urgent"
: "неотложный"

, "%s's personal tasks"
: "%s личные задачи"

, "GENDER_Task"
: ""

, "Due"
: "Окончание"

, "Class"
: ""

, "Description"
: "Описание"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Предложение"

, "Telephone"
: "Телефон"

, "Email"
: "Электронная почта"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Все задачи моих списков задач"

, "My open tasks"
: "Мои открытые задачи"

, "My open tasks this week"
: "Мои открытые задачи на этой неделе"

, "All tasks for me"
: "Все задачи для меня"

, "All tasks that I am responsible for"
: "Все задачи, за которые я отвечаю"

, "Last modified by me"
: "Последний раз изменено мной"

, "All tasks that I have last modified"
: "Все задачи, последний раз которые были изменены мной"

, "Tasks without responsible"
: "Задача без ответственного лица"

, "manage shared task lists"
: "управление списками общих задач"

, "Create new shared tasks lists"
: "Создать новый список общих задач"

, "manage shared tasks favorites"
: "управлять избранным в общих задачах"

, "Create or update shared tasks favorites"
: "Создание или обновление избранных в общих задачах"

, "Status"
: "Состояние"

, "Do you really want to delete the selected task?"
: "Вы действительно хотите удалить выбранную задачу"

, "Task"
: "Задачи"

, "to do list"
: "список работ"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
